@@ -194,12 +194,37 @@ class TestGoogleCodeWikiImporter(TestCase):
         project, user = Mock(), Mock()
         extractor.return_value.get_wiki_pages.return_value = [('name', 'url')]
         extractor.gc_project_name = 'testproject'
+        wp.return_value.name = 'name'
+        c.app = project.install_app.return_value
+        c.app.config.options.mount_point = 'wiki'
+        c.app.config.options.import_id = {
+                'source': 'Google Code',
+                'project_name': 'testproject',
+            }
+        c.app.config.options.get = lambda *a: getattr(c.app.config.options, *a)
+        c.app.url = 'foo'
         GoogleCodeWikiImporter().import_tool(project, user, project_name='testproject')
         extractor.assert_called_once_with('testproject')
         project.install_app.assert_called_once_with('Wiki',
                 mount_point='wiki',
-                mount_label='Wiki')
+                mount_label='Wiki',
+                import_id={
+                        'source': 'Google Code',
+                        'project_name': 'testproject',
+                    },
+            )
         self.assertEqual(Page_upsert.call_count, 1)
+        self.assertEqual(Page_upsert.return_value.import_id, {
+                'source': 'Google Code',
+                'project_name': 'testproject',
+                'source_id': 'name',
+            })
+        M.AuditLog.log.assert_called_once_with(
+                'import tool wiki from testproject on Google Code',
+                project=project,
+                user=user,
+                url='foo',
+            )
         g.post_event.assert_called_once_with('project_updated')
 
     @patch('googlecodewikiimporter.importer.h')
